@@ -5,16 +5,23 @@ import matplotlib.ticker as mtick
 import matplotlib.dates as mdates
 
 
+@pd.api.extensions.register_series_accessor("Drawdown")
 class Drawdown:
     """Given a Wealth Index DataFrame, will produce usefull drawdown metrics"""
 
-    def __init__(self, wealth_index_series: pd.Series):
-        self.wealth_index_series = wealth_index_series
-        peaks = self.wealth_index_series.cummax()
-        self.drawdown_series = (self.wealth_index_series - peaks) / peaks
-        self.drawdown_series.rename('Drawdown', inplace=True)
+    def __init__(self, pandas_obj):
+        self._validate(pandas_obj)
+        peaks = pandas_obj.cummax()
+        self._obj = (pandas_obj - peaks) / peaks
+        self._obj.rename('Drawdown', inplace=True)
 
-    def get_drawdown(self):
+    @staticmethod
+    def _validate(obj):
+        assert not pd.isnull(obj[0])
+        assert isinstance(obj.index, pd.DatetimeIndex)
+
+    @property
+    def drawdown(self):
         """
         Returns the pandas Series with Drawdown calculated.
 
@@ -24,36 +31,38 @@ class Drawdown:
             The Drawdown series
         """
 
-        return self.drawdown_series
+        return self._obj
 
-    def get_max_drawdown(self):
+    @property
+    def max_drawdown(self):
         """Returns the maximum drawdown"""
-        return self.drawdown_series.min()
+        return self._obj.min()
 
-    def compute_drawdown_lagoons_durations(self):
+    @property
+    def durations(self):
         """
         Returns a pd.Series where the index is the last day of the recovery of a lagoon
         and the value the total days since the previous max value for this lagoon
         """
         # find all the locations where the drawdown == 0
         zero_locations = np.unique(
-            np.r_[(self.drawdown_series == 0).values.nonzero()[0], len(self.drawdown_series) - 1]
+            np.r_[(self._obj == 0).values.nonzero()[0], len(self._obj) - 1]
         )
         # also assign the dates so we know when things were not sinking
-        zero_loc_s = pd.Series(zero_locations, index=self.drawdown_series.index[zero_locations])
+        zero_loc_s = pd.Series(zero_locations, index=self._obj.index[zero_locations])
         # do a shift to show what is the last and previous non zero dates
         df = zero_loc_s.to_frame('zero_loc')
         df['prev_zloc'] = zero_loc_s.shift()
         # keep only the dates where the difference is more than 1
         # that denotes the lagoons
         df = df[df['zero_loc'] - df['prev_zloc'] > 1].astype(int)
-        item = self.drawdown_series.index.__getitem__
+        item = self._obj.index.__getitem__
         df['Durations'] = df['zero_loc'].map(item) - df['prev_zloc'].map(item)
-        df = df.reindex(self.drawdown_series.index)
+        df = df.reindex(self._obj.index)
         df = df.dropna()
         return df['Durations']
 
-    def plot_drawdown(self, ax=None, **kwargs):
+    def plot(self, ax=None, **kwargs):
         """
         Plots the Drawdown
 
@@ -69,7 +78,7 @@ class Drawdown:
         if ax is None:
             ax = plt.gca()
 
-        series_to_plot = self.drawdown_series * 100
+        series_to_plot = self._obj * 100
         series_to_plot.plot(ax=ax, lw=2, kind='area', color='red', alpha=0.3, **kwargs)
         ax.yaxis.grid(linestyle=':')
         ax.xaxis.grid(linestyle=':')
